@@ -24,6 +24,8 @@ require(psych)
 require(psychometric)
 require(reshape2)
 require(rmarkdown)
+require(shiny)
+require(shinyBS)
 require(ShinyItemAnalysis)
 require(shinyjs)
 require(stringr)
@@ -41,23 +43,11 @@ options(shiny.maxRequestSize = 30*1024^2)
 # FUNCTIONS ######
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-# Difficulty/Discrimination plot
-source("DDplot.R")
-
-# Distractors analysis
-source("DistractorAnalysis.R")
-source("plotDistractorAnalysis.R")
-
-# DIF logistic regression plot
-source("plotDIFLogistic.R")
-
-# DIF IRT regression plot
-source("plotDIFirt.R")
-
 # WrightMap
-source("wrightMap.R")
-source("itemClassic.R")
-source("personHist.R")
+source("functions/wrightMap.R")
+source("functions/itemClassic.R")
+source("functions/personHist.R")
+source("functions/theme_shiny.R")
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 # SERVER SCRIPT ######
@@ -132,8 +122,8 @@ function(input, output, session) {
         }
       } else {
         validate(
-          need(ncol(dataset$answers) == length(dataset$key), "Length of key is not the same as
-               number of items in the main data set!"),
+          need(ncol(dataset$answers) == length(dataset$key),
+          "The length of key need to be the same as number of columns in the main dataset!"),
           errorClass = "error_dimension"
           )
       }
@@ -156,7 +146,7 @@ function(input, output, session) {
       if (datasetName == "GMAT"){
         group <- test[, "group"]
       } else {
-        if (datasetName == "dataMedical"){
+        if (datasetName == "dataMedical" | datasetName == "HCI"){
           group <- test[, "gender"]
         } else {
           group <- test[, ncol(test), with = FALSE]
@@ -176,7 +166,7 @@ function(input, output, session) {
       } else {
         validate(
           need(nrow(dataset$answers) == length(dataset$group),
-            "Length of group is not the same as number of observation in the main data set!"),
+            "The length of group need to be the same as number of observation in the main dataset!"),
           errorClass = "error_dimension"
         )
       }
@@ -196,10 +186,18 @@ function(input, output, session) {
       do.call(data, args = list(paste0(datasetName, "test"), package = packageName))
       test = data.table(get(paste0(datasetName, "test")))
 
-      if (datasetName == "GMAT" | datasetName == "dataMedical"){
+      if (datasetName == "GMAT"){
         criterion_variable <- test[, "criterion"]
       } else {
-        criterion_variable <- "missing"
+        if (datasetName == "dataMedical"){
+          criterion_variable <- test[, "StudySuccess"]
+        } else {
+          if (datasetName == "HCI"){
+            criterion_variable <- test[, "major"]
+          } else {
+            criterion_variable <- "missing"
+          }
+        }
       }
 
       dataset$criterion_variable = criterion_variable
@@ -221,7 +219,7 @@ function(input, output, session) {
       } else {
         validate(
           need(nrow(dataset$answers) == length(dataset$criterion_variable),
-               "Length of criterion variable is not the same as number of observation in the main data set!"),
+               "The length of criterion variable need to be the same as number of observation in the main dataset!"),
           errorClass = "error_dimension"
         )
       }
@@ -266,7 +264,8 @@ function(input, output, session) {
         if (is.null(input$criterion_variable)){
           criterion_variable <- "missing"
         } else {
-          criterion_variable <- read.csv(input$criterion_variable$datapath, header = input$header,
+          criterion_variable <- read.csv(input$criterion_variable$datapath,
+                                         header = input$header,
                                          sep = input$sep)
           criterion_variable <- unlist(criterion_variable)
         }
@@ -308,7 +307,7 @@ function(input, output, session) {
     if (any(dataset$criterion_variable == "missing")){
       warni_criterion_variable <- "The criterion variable is not provided! Predictive validity analysis is not available!"
     } else {
-      if (nrow(dataset$answers) != length(dataset$group)){
+      if (nrow(dataset$answers) != length(dataset$criterion_variable)){
         error_criterion_variable <- "The length of criterion variable need to be the same as number of observations in the main dataset!"
         error_setting <- T
       }
@@ -543,7 +542,8 @@ function(input, output, session) {
       "logregSlider",
       "zlogregSlider",
       "zlogreg_irtSlider",
-      "nlsSlider",
+      "slider_nlr_3P_item",
+      "slider_nlr_4P_item",
       "multiSlider",
       "difMHSlider_item",
       "diflogSlider",
@@ -565,7 +565,8 @@ function(input, output, session) {
     updateSliderInput(session = session, inputId = "logregSlider", max = itemCount)
     updateSliderInput(session = session, inputId = "zlogregSlider", max = itemCount)
     updateSliderInput(session = session, inputId = "zlogreg_irtSlider", max = itemCount)
-    updateSliderInput(session = session, inputId = "nlsSlider", max = itemCount)
+    updateSliderInput(session = session, inputId = "slider_nlr_3P_item", max = itemCount)
+    updateSliderInput(session = session, inputId = "slider_nlr_4P_item", max = itemCount)
     updateSliderInput(session = session, inputId = "multiSlider", max = itemCount)
     updateSliderInput(session = session, inputId = "difMHSlider_item", max = itemCount)
     updateSliderInput(session = session, inputId = "diflogSlider", max = itemCount)
@@ -586,37 +587,37 @@ function(input, output, session) {
   # SUMMARY ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("Summary.R", local = T)
+  source("server/Summary.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # VALIDITY ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("Validity.R", local = T)
+  source("server/Validity.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # TRADITIONAL ANALYSIS ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("TraditionalAnalysis.R", local = T)
+  source("server/TraditionalAnalysis.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # REGRESSION ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("Regression.R", local = T)
+  source("server/Regression.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # IRT MODELS WITH MIRT ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("IRT.R", local = T)
+  source("server/IRT.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # DIF/FAIRNESS ######
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-  source("DIF.R", local = T)
+  source("server/DIF.R", local = T)
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # REPORTS ######
@@ -653,55 +654,60 @@ function(input, output, session) {
 
   irtInput <- reactive({
     type = input$irt_type_report
-    if (type=="rasch"){out=raschInput_mirt()}
-    if (type=="1pl") {out=oneparamirtInput_mirt()}
-    if (type=="2pl") {out=twoparamirtInput_mirt()}
-    if (type=="3pl") {out=threeparamirtInput_mirt()}
-    if (type=="none") {out=""}
+    if (type == "rasch"){out = raschInput_mirt()}
+    if (type == "1pl")  {out = oneparamirtInput_mirt()}
+    if (type == "2pl")  {out = twoparamirtInput_mirt()}
+    if (type == "3pl")  {out = threeparamirtInput_mirt()}
+    if (type == "4pl")  {out = irt_4PL_icc_Input()}
+    if (type == "none") {out = ""}
 
     out
   })
 
   irtiicInput <- reactive({
     type = input$irt_type_report
-    if (type=="rasch"){out=raschiicInput_mirt()}
-    if (type=="1pl") {out=oneparamirtiicInput_mirt()}
-    if (type=="2pl") {out=twoparamirtiicInput_mirt()}
-    if (type=="3pl") {out=threeparamirtiicInput_mirt()}
-    if (type=="none") {out=""}
+    if (type == "rasch"){out = raschiicInput_mirt()}
+    if (type == "1pl")  {out = oneparamirtiicInput_mirt()}
+    if (type == "2pl")  {out = twoparamirtiicInput_mirt()}
+    if (type == "3pl")  {out = threeparamirtiicInput_mirt()}
+    if (type == "4pl")  {out = irt_4PL_iic_Input()}
+    if (type == "none") {out = ""}
 
     out
   })
 
   irttifInput <- reactive({
     type = input$irt_type_report
-    if (type=="rasch"){out=raschtifInput_mirt()}
-    if (type=="1pl") {out=oneparamirttifInput_mirt()}
-    if (type=="2pl") {out=twoparamirttifInput_mirt()}
-    if (type=="3pl") {out=threeparamirttifInput_mirt()}
-    if (type=="none") {out=""}
+    if (type == "rasch"){out = raschtifInput_mirt()}
+    if (type == "1pl")  {out = oneparamirttifInput_mirt()}
+    if (type == "2pl")  {out = twoparamirttifInput_mirt()}
+    if (type == "3pl")  {out = threeparamirttifInput_mirt()}
+    if (type == "4pl")  {out = irt_4PL_tif_Input()}
+    if (type == "none") {out = ""}
 
     out
   })
 
   irtcoefInput <- reactive({
     type = input$irt_type_report
-    if (type=="rasch"){out=raschcoefInput_mirt()}
-    if (type=="1pl") {out=oneparamirtcoefInput_mirt()}
-    if (type=="2pl") {out=twoparamirtcoefInput_mirt()}
-    if (type=="3pl") {out=threeparamirtcoefInput_mirt()}
-    if (type=="none") {out=""}
+    if (type == "rasch"){out = raschcoefInput_mirt()}
+    if (type == "1pl")  {out = oneparamirtcoefInput_mirt()}
+    if (type == "2pl")  {out = twoparamirtcoefInput_mirt()}
+    if (type == "3pl")  {out = threeparamirtcoefInput_mirt()}
+    if (type == "4pl")  {out = irt_4PL_coef_Input()}
+    if (type == "none") {out = ""}
 
     out
   })
 
   irtfactorInput <- reactive({
     type = input$irt_type_report
-    if (type=="rasch"){out=raschFactorInput_mirt()}
-    if (type=="1pl") {out=oneparamirtFactorInput_mirt()}
-    if (type=="2pl") {out=twoparamirtFactorInput_mirt()}
-    if (type=="3pl") {out=threeparamirtFactorInput_mirt()}
-    if (type=="none") {out=""}
+    if (type == "rasch"){out = raschFactorInput_mirt()}
+    if (type == "1pl")  {out = oneparamirtFactorInput_mirt()}
+    if (type == "2pl")  {out = twoparamirtFactorInput_mirt()}
+    if (type == "3pl")  {out = threeparamirtFactorInput_mirt()}
+    if (type == "4pl")  {out = irt_4PL_factorscores_plot_Input()}
+    if (type == "none") {out = ""}
 
     out
   })
@@ -762,10 +768,10 @@ function(input, output, session) {
            graf = report_distractor_plot(),
            incProgress(0.25),
            # regression
-           logreg = logreg_plot_Input(),
-           zlogreg = z_logreg_plot_Input(),
-           zlogreg_irt = z_logreg_irt_plot_Input(),
-           nlsplot = nlr_plot_Input(),
+           # logreg = logreg_plot_Input(),
+           # zlogreg = z_logreg_plot_Input(),
+           # zlogreg_irt = z_logreg_irt_plot_Input(),
+           # nlsplot = nlr_3P_plot_Input(),
            multiplot = multiplotReportInput(),
            incProgress(0.05),
            # irt
@@ -778,25 +784,25 @@ function(input, output, session) {
            irtfactor = irtfactorInput(),
            incProgress(0.25),
            # DIF
+           ### presence of group vector
            isGroupPresent = groupPresent(),
+           ### histograms by group
            histCheck = input$histCheck,
            resultsgroup = {if (groupPresent()) {if (input$histCheck) {resultsgroupInput()}}},
            histbyscoregroup0 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup0Input()}}},
            histbyscoregroup1 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup1Input()}}},
+           ### delta plot
            deltaplotCheck = input$deltaplotCheck,
            deltaplot = {if (groupPresent()) {if (input$deltaplotCheck) {deltaplotInput_report()}}},
            DP_text_normal = {if (groupPresent()) {if (input$deltaplotCheck) {deltaGpurn_report()}}},
+           ### logistic regression
            logregCheck = input$logregCheck,
            DIF_logistic_plot = {if (groupPresent()) {if (input$logregCheck) {DIF_logistic_plotReport()}}},
            DIF_logistic_print = {if (groupPresent()) {if (input$logregCheck) {model_DIF_logistic_print_report()}}},
-           #plot_DIF_logistic = {if (groupPresent()) {plot_DIF_logisticInput()}},
-           #plot_DIF_logistic_IRT_Z = {if (groupPresent()) {plot_DIF_logistic_IRT_ZInput()}},
-           #plot_DIF_NLR = {if (groupPresent()) {plot_DIF_NLRInput()}},
-           #plot_DIF_IRT_Lord = {if (groupPresent()) {plot_DIF_IRT_LordInput()}},
-           #plot_DIF_IRT_Raju = {if (groupPresent()) {plot_DIF_IRT_RajuInput()}},
+           ### DDF multinomial
            multiCheck = input$multiCheck,
-           model_DDF_print = {if (groupPresent()) {if (input$multiCheck) {model_DDF_print_report()}}},
-           plot_DDFReportInput = {if (groupPresent()) {if (input$multiCheck) {plot_DDFReportInput()}}},
+           DDF_multinomial_print = {if (groupPresent()) {if (input$multiCheck) {model_DDF_print_report()}}},
+           DDF_multinomial_plot = {if (groupPresent()) {if (input$multiCheck) {plot_DDFReportInput()}}},
            incProgress(0.25)
       )
     })
@@ -810,15 +816,11 @@ function(input, output, session) {
 
   })
 
-
-
-
   output$report <- downloadHandler(
     filename = reactive({paste0("report.", input$report_format)}),
     content = function(file) {
 
       reportPath <- file.path(getwd(), paste0("report", formatInput(), ".Rmd"))
-      # file.copy("report.Rmd", tempReport, overwrite = TRUE)
       parameters <- list(# header
                          author = input$reportAuthor,
                          dataset = input$reportDataName,
@@ -849,10 +851,10 @@ function(input, output, session) {
                          hist_distractor_by_group = distractor_histogram_Input(),
                          graf = report_distractor_plot(),
                          # regression
-                         logreg = logreg_plot_Input(),
-                         zlogreg = z_logreg_plot_Input(),
-                         zlogreg_irt = z_logreg_irt_plot_Input(),
-                         nlsplot = nlr_plot_Input(),
+                         # logreg = logreg_plot_Input(),
+                         # zlogreg = z_logreg_plot_Input(),
+                         # zlogreg_irt = z_logreg_irt_plot_Input(),
+                         # nlsplot = nlr_3P_plot_Input(),
                          multiplot = multiplotReportInput(),
                          # irt
                          wrightMap = oneparamirtWrightMapReportInput_mirt(),
@@ -863,25 +865,25 @@ function(input, output, session) {
                          irtcoef = irtcoefInput(),
                          irtfactor = irtfactorInput(),
                          # DIF
+                         ### presence of group vector
                          isGroupPresent = groupPresent(),
+                         ### histograms by groups
                          histCheck = input$histCheck,
                          resultsgroup = {if (groupPresent()) {if (input$histCheck) {resultsgroupInput()}}},
                          histbyscoregroup0 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup0Input()}}},
                          histbyscoregroup1 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup1Input()}}},
+                         ### delta plot
                          deltaplotCheck = input$deltaplotCheck,
-                         deltaplot = {if (groupPresent()) {if (input$deltaplotCheck) {deltaplotInput_report()}}},
-                         DP_text_normal = {if (groupPresent()) {if (input$deltaplotCheck) {deltaGpurn_report()}}},
+                         DIF_deltaplot = {if (groupPresent()) {if (input$deltaplotCheck) {deltaplotInput_report()}}},
+                         DIF_deltaplot_text = {if (groupPresent()) {if (input$deltaplotCheck) {deltaGpurn_report()}}},
+                         ### logistic regression
                          logregCheck = input$logregCheck,
                          DIF_logistic_plot = {if (groupPresent()) {if (input$logregCheck) {DIF_logistic_plotReport()}}},
                          DIF_logistic_print = {if (groupPresent()) {if (input$logregCheck) {model_DIF_logistic_print_report()}}},
-                         #plot_DIF_logistic = {if (groupPresent()) {plot_DIF_logisticInput()}},
-                         #plot_DIF_logistic_IRT_Z = {if (groupPresent()) {plot_DIF_logistic_IRT_ZInput()}},
-                         #plot_DIF_NLR = {if (groupPresent()) {plot_DIF_NLRInput()}},
-                         #plot_DIF_IRT_Lord = {if (groupPresent()) {plot_DIF_IRT_LordInput()}},
-                         #plot_DIF_IRT_Raju = {if (groupPresent()) {plot_DIF_IRT_RajuInput()}},
+                         ### multinomial regression
                          multiCheck = input$multiCheck,
-                         model_DDF_print = {if (groupPresent()) {if (input$multiCheck) {model_DDF_print_report()}}},
-                         plot_DDFReportInput = {if (groupPresent()) {if (input$multiCheck) {plot_DDFReportInput()}}}
+                         DDF_multinomial_print = {if (groupPresent()) {if (input$multiCheck) {model_DDF_print_report()}}},
+                         DDF_multinomial_plot = {if (groupPresent()) {if (input$multiCheck) {plot_DDFReportInput()}}}
       )
       rmarkdown::render(reportPath, output_file = file,
                         params = parameters, envir = new.env(parent = globalenv()))
